# Chercher 🔍

**Chercher** is a versatile and personal search engine that makes it easy to index and search all kinds of documents and webpages. Plus, if you want to add even more features, you can use its plugin system to expand what it can do.

## Features

1. **Plugins everywhere**: Enhance Chercher with a variety of plugins. If you can’t find what you need, creating a new plugin is a breeze!
2. **Powered by SQLite's FTS5**: Chercher takes advantage of SQLite's Full-Text-Search (FTS5) for a fast and efficient searching across your content.
3. **BM25 for relevant search results**: Get the most relevant search results with the BM25 ranking algorithm.
4. **Progressive indexing**: Add documents and start searching immediately. No waiting required!
5. **Easy to use CLI**: Interact with Chercher through a straightforward CLI.

## Motivation

Building my own personal search engine has been a dream of mine for a while, but I had a tough time creating something I was really happy with. Almost a year ago, I took my first shot at it with [winzig](https://github.com/dnlzrgz/winzig), but after some ups and downs, I decided to switch gears and try again with [housaku](https://github.com/dnlzrgz/housaku). I got a bit too ambitious, and with life getting in the way, I eventually had to put the project on hold.

Luckily for me I learned a lot about how search engines work, the ins and outs of some ranking algorithms, and the best practices to follow (and the pitfalls to avoid).

## Installing

> [!NOTE]
> TODO

## Usage

> [!NOTE]
> TODO

## Plugins

> [!NOTE]
> TODO
